@@ -1,5 +1,5 @@
-data("laparoscopy")
-Data <- laparoscopy[-c(83:138), ]
+data("laparotomy")
+Data <- laparotomy[-c(83:138), ]
 markers <- Data[, -1]
 status <- factor(Data$group, levels = c("not_needed", "needed"))
 
@@ -29,7 +29,7 @@ for (standardize in c(
 
 ###############################################################################
 
-test <- laparoscopy[c(83:138), -1]
+test <- laparotomy[c(83:138), -1]
 
 load("result_data/test_std.test.rda")
 
